@@ -49,9 +49,9 @@ class Renderer(_Renderer):
     
     def _absolutize(self, html):
         def _replace(match):
-            return self._get_url(match.group(1).replace(self.globals['site']['base_url'], ''), True)
+            return self._get_url(match.group(1).replace(self.globals['site']['base_url'], '', 1), True)
         
-        return sub(r'(?<==")(/[^"]*)', _replace, html)
+        return sub(r'(?<==")({0}[^"]*)'.format(absurl(self.globals['site']['base_url']), ''), _replace, html)
     
     def _date(self, ts, format = '%A, %B %d, %Y'):
         if ts is None:
@@ -63,14 +63,16 @@ class Renderer(_Renderer):
         return absurl(self.globals['site']['base_url'], self.globals['site']['assets_url'], asset)
     
     def _get_url(self, url = '', absolute = False):
+        parts = [self.globals['site']['base_url'], url]
         domain = self.globals['site']['domain']
         
-        if not absolute or not domain:
-            domain = ''
-        elif not domain.startswith(('http://', 'https://')):
-            domain = 'http://' + domain
+        if absolute and domain:
+            if not domain.startswith(('http://', 'https://')):
+                domain = 'http://' + domain
+            
+            parts.insert(0, domain)
         
-        return absurl(domain, self.globals['site']['base_url'], url)
+        return absurl(*parts)
     
     
     def from_string(self, source, vars_ = {}):
